@@ -93,10 +93,10 @@ class Field:
 
 
 class MathOperator(Enum):
-    ADD = auto()
-    MUL = auto()
-    SUB = auto()
-    DIV = auto()
+    ADD = "+"
+    MUL = "*"
+    SUB = "-"
+    DIV = "/"
 
 
 @dataclass
@@ -109,7 +109,7 @@ class ComplexMathField:
 
     def __repr__(self):
         if isinstance(self.operator, MathOperator):
-            repr = str(self.first_operand) + " " + self.operator.name + " " + str(self.second_operand)
+            repr = str(self.first_operand) + " " + self.operator.value + " " + str(self.second_operand)
         else:
             repr = str(self.first_operand) + " " + self.operator + " " + str(self.second_operand)
         if self.percent is not None and self.percent:
@@ -135,9 +135,9 @@ class SQLOperator(Enum):
 
 @dataclass
 class ComplexConditionalField:
-    field: Field
+    field: Union[str, Field]
     operator: Union[SQLOperator, str]
-    value: Union[float, str]
+    value: Union[bool, float, str]
     else_clause: Union[bool, float, str]
     then_clause: Optional[Union[bool, float, str]] = None
     alias: Optional[str] = None
